import { ElementRef, EventEmitter, QueryList } from '@angular/core';
import { LfRouter } from '@lightweightform/core';
import { Value } from './value';
/**
 * Abstract class used to represent typical "inline-able" values.
 */
export declare abstract class FocusableValue extends Value {
    /**
     * Event emitter which emits an event whenever the component's DOM input is
     * focused.
     */
    focus: EventEmitter<FocusEvent>;
    /**
     * Event emitter which emits an event whenever the component's DOM input is
     * blurred.
     */
    blur: EventEmitter<FocusEvent>;
    /**
     * Add an `lf-focusable-value` class to components.
     */
    _classLfFocusableField: boolean;
    /**
     * Target elements that should be the target of focus/blur events; the first
     * element of que query list is the one that will be focused on route change
     * or when demanded via `focus()`.
     */
    protected targets: QueryList<ElementRef>;
    protected lfRouter: LfRouter;
    /**
     * Disposer for the "auto-focus" of the field when it becomes active.
     */
    private disposeOnActive;
    ngOnInit(): void;
    ngOnDestroy(): void;
    /**
     * Focus this component.
     */
    triggerFocus(): void;
    /**
     * Action to run whenever a focusable part of the field is focused.
     * @param evt `focus` event.
     */
    _onFocus(evt: FocusEvent): void;
    /**
     * Action to run whenever a focusable part of the field is blurred.
     * @param evt `blur` event.
     */
    _onBlur(evt: FocusEvent): void;
}
