import { FocusableValue } from './focusable-value';
/**
 * Type of an option supported by components which restrict their values via
 * options.
 */
export interface Option<T = any> {
    /**
     * Value of the option.
     */
    value: T;
    /**
     * Human-readable string to represent the option.
     */
    label: string;
    /**
     * Code of the option.
     */
    code?: string;
    /**
     * Help message associated with the option.
     */
    helpMessage?: string;
    /**
     * Whether the option should be disabled.
     */
    isDisabled?: boolean;
}
/**
 * Class which represents a component whose value may be restricted by a set of
 * options.
 */
export declare abstract class ValueWithOptions extends FocusableValue {
    /**
     * Selectable options.
     */
    readonly options: Option[];
    /**
     * Text to be shown when there are no options available.
     */
    readonly noOptionsText: string;
}
