import { ElementRef, TemplateRef } from '@angular/core';
import { FocusableValue } from '../../abstract/focusable-value';
import { TableHeaderDirective } from '../../directives/table-header/table-header.directive';
import { ActionsMenuAction } from '../actions-menu/actions-menu.component';
/**
 * HTML string of the table component.
 */
export declare const tableComponentHtml: string;
/**
 * Default width of the selection column (in `px`).
 */
export declare const SELECTION_COLUMN_WIDTH: number;
/**
 * LF table component.
 */
export declare class TableComponent extends FocusableValue {
    /**
     * Height (in `px`) of a single row (virtual scroll settings). All rows must
     * have the same height.
     */
    rowHeight: number;
    /**
     * Maximum number of visible rows at any given time (virtual scroll settings).
     */
    maxVisibleRows: number;
    /**
     * Number of "excess" rows rendered before and after the visible rows (virtual
     * scroll settings).
     */
    excessRows: number;
    _tableHeader: TableHeaderDirective;
    rowTemplate: TemplateRef<any>;
    noRowsTemplate: TemplateRef<any>;
    _headerTableContainer: ElementRef;
    _bodyTableContainer: ElementRef;
    private _virtualScroll;
    private _selectedRows;
    private _lastSelectedIndex;
    private _disposeScroll;
    ngOnInit(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    readonly addRowText: string;
    readonly removeRowsText: string;
    readonly noRowsText: string;
    columnLabel(columnId: string): string;
    readonly _tableActions: ActionsMenuAction[];
    numberOfColumns(includeScrollbarColumn: boolean): number | null;
    tableMinWidth(includeScrollbarColumn: boolean): number | null;
    tableMaxWidth(includeScrollbarColumn: boolean): number | null;
    columnWidths(includeScrollbarColumn: boolean): string[];
    readonly verticalScrollbarWidth: number;
    readonly isEditable: boolean;
    readonly numberOfRowsSelected: number;
    readonly allRowsSelected: boolean;
    readonly noRowsSelected: boolean;
    getRowSelectedStatus(index: number): boolean;
    pushRow(): void;
    setRowSelectedStatus(index: number, selectedStatus: boolean): void;
    setRowSelectedStatusFromLastSelected(index: number, selectedStatus: boolean): void;
    unselectAllRows(): void;
    setAllRowsSelectedStatus(selectedStatus: boolean): void;
    toggleAllRowsSelectedStatus(): void;
    removeSelectedRows(): void;
    _onClickRemoveRows(): void;
    _onClickNewRow(): void;
    /**
     * @override
     */
    protected validatePath(): void;
}
