import { LfI18n, LfRouter, LfStorage } from '@lightweightform/core';
import { ValidationError } from '@lightweightform/storage';
import { MarkdownService } from 'ngx-markdown';
/**
 * Service used to format validation messages' to HTML messages
 */
export declare class ValidationMessagesService {
    private lfStorage;
    private lfI18n;
    private lfRouter;
    private markdownService;
    constructor(lfStorage: LfStorage, lfI18n: LfI18n, lfRouter: LfRouter, markdownService: MarkdownService);
    /**
     * Formats a validation error message assuming the Markdown standard
     * specification. Applies some pre processors, such as:
     * - labelLink pre-processor: converts a tag with format "@${path}@" to a
     * hyperlink to the given path and a message specified in that path's
     * component.
     * @param path Path for the value which contains the error.
     * @param validationError Validation error with the preformatted message.
     * @returns Formatted message.
     */
    formatMessage(path: string, validationError: ValidationError): string;
    /**
     * Gets the label associated to the given path.
     * @param path Path from which to fetch label.
     * @returns Label of given path.
     */
    getLabel(path: string): string;
    protected _parseMD(message: string): string;
    protected _applyPreProcessors(message: string): string;
    protected _preProcessorLabelLinks(message: string): string;
}
